@@ -10,10 +10,10 @@ extern void _GBaseFinalizeFunc_c_wrapper();
 extern void _GBaseFinalizeFunc_c_wrapper_once();
 extern void _GBaseInitFunc_c_wrapper();
 extern void _GBaseInitFunc_c_wrapper_once();
-extern void _GBindingTransformFunc_c_wrapper();
-extern void _GBindingTransformFunc_c_wrapper_once();
-extern void _GBoxedCopyFunc_c_wrapper();
-extern void _GBoxedCopyFunc_c_wrapper_once();
+extern int _GBindingTransformFunc_c_wrapper();
+extern int _GBindingTransformFunc_c_wrapper_once();
+extern void* _GBoxedCopyFunc_c_wrapper();
+extern void* _GBoxedCopyFunc_c_wrapper_once();
 extern void _GBoxedFreeFunc_c_wrapper();
 extern void _GBoxedFreeFunc_c_wrapper_once();
 extern void _GCallback_c_wrapper();
@@ -38,14 +38,14 @@ extern void _GObjectGetPropertyFunc_c_wrapper();
 extern void _GObjectGetPropertyFunc_c_wrapper_once();
 extern void _GObjectSetPropertyFunc_c_wrapper();
 extern void _GObjectSetPropertyFunc_c_wrapper_once();
-extern void _GSignalAccumulator_c_wrapper();
-extern void _GSignalAccumulator_c_wrapper_once();
-extern void _GSignalEmissionHook_c_wrapper();
-extern void _GSignalEmissionHook_c_wrapper_once();
+extern int _GSignalAccumulator_c_wrapper();
+extern int _GSignalAccumulator_c_wrapper_once();
+extern int _GSignalEmissionHook_c_wrapper();
+extern int _GSignalEmissionHook_c_wrapper_once();
 extern void _GToggleNotify_c_wrapper();
 extern void _GToggleNotify_c_wrapper_once();
-extern void _GTypeClassCacheFunc_c_wrapper();
-extern void _GTypeClassCacheFunc_c_wrapper_once();
+extern int _GTypeClassCacheFunc_c_wrapper();
+extern int _GTypeClassCacheFunc_c_wrapper_once();
 extern void _GTypeInterfaceCheckFunc_c_wrapper();
 extern void _GTypeInterfaceCheckFunc_c_wrapper_once();
 extern void _GTypePluginCompleteInterfaceInfo_c_wrapper();
@@ -64,76 +64,82 @@ extern void _GChildWatchFunc_c_wrapper();
 extern void _GChildWatchFunc_c_wrapper_once();
 extern void _GClearHandleFunc_c_wrapper();
 extern void _GClearHandleFunc_c_wrapper_once();
-extern void _GCompareDataFunc_c_wrapper();
-extern void _GCompareDataFunc_c_wrapper_once();
-extern void _GCompareFunc_c_wrapper();
-extern void _GCompareFunc_c_wrapper_once();
-extern void _GCopyFunc_c_wrapper();
-extern void _GCopyFunc_c_wrapper_once();
+extern int32_t _GCompareDataFunc_c_wrapper();
+extern int32_t _GCompareDataFunc_c_wrapper_once();
+extern int32_t _GCompareFunc_c_wrapper();
+extern int32_t _GCompareFunc_c_wrapper_once();
+extern void* _GCopyFunc_c_wrapper();
+extern void* _GCopyFunc_c_wrapper_once();
 extern void _GDataForeachFunc_c_wrapper();
 extern void _GDataForeachFunc_c_wrapper_once();
 extern void _GDestroyNotify_c_wrapper();
 extern void _GDestroyNotify_c_wrapper_once();
-extern void _GDuplicateFunc_c_wrapper();
-extern void _GDuplicateFunc_c_wrapper_once();
-extern void _GEqualFunc_c_wrapper();
-extern void _GEqualFunc_c_wrapper_once();
+extern void* _GDuplicateFunc_c_wrapper();
+extern void* _GDuplicateFunc_c_wrapper_once();
+extern int _GEqualFunc_c_wrapper();
+extern int _GEqualFunc_c_wrapper_once();
+extern void _GErrorClearFunc_c_wrapper();
+extern void _GErrorClearFunc_c_wrapper_once();
+extern void _GErrorCopyFunc_c_wrapper();
+extern void _GErrorCopyFunc_c_wrapper_once();
+extern void _GErrorInitFunc_c_wrapper();
+extern void _GErrorInitFunc_c_wrapper_once();
 extern void _GFreeFunc_c_wrapper();
 extern void _GFreeFunc_c_wrapper_once();
 extern void _GFunc_c_wrapper();
 extern void _GFunc_c_wrapper_once();
 extern void _GHFunc_c_wrapper();
 extern void _GHFunc_c_wrapper_once();
-extern void _GHRFunc_c_wrapper();
-extern void _GHRFunc_c_wrapper_once();
-extern void _GHashFunc_c_wrapper();
-extern void _GHashFunc_c_wrapper_once();
-extern void _GHookCheckFunc_c_wrapper();
-extern void _GHookCheckFunc_c_wrapper_once();
-extern void _GHookCheckMarshaller_c_wrapper();
-extern void _GHookCheckMarshaller_c_wrapper_once();
-extern void _GHookCompareFunc_c_wrapper();
-extern void _GHookCompareFunc_c_wrapper_once();
+extern int _GHRFunc_c_wrapper();
+extern int _GHRFunc_c_wrapper_once();
+extern uint32_t _GHashFunc_c_wrapper();
+extern uint32_t _GHashFunc_c_wrapper_once();
+extern int _GHookCheckFunc_c_wrapper();
+extern int _GHookCheckFunc_c_wrapper_once();
+extern int _GHookCheckMarshaller_c_wrapper();
+extern int _GHookCheckMarshaller_c_wrapper_once();
+extern int32_t _GHookCompareFunc_c_wrapper();
+extern int32_t _GHookCompareFunc_c_wrapper_once();
 extern void _GHookFinalizeFunc_c_wrapper();
 extern void _GHookFinalizeFunc_c_wrapper_once();
-extern void _GHookFindFunc_c_wrapper();
-extern void _GHookFindFunc_c_wrapper_once();
+extern int _GHookFindFunc_c_wrapper();
+extern int _GHookFindFunc_c_wrapper_once();
 extern void _GHookFunc_c_wrapper();
 extern void _GHookFunc_c_wrapper_once();
 extern void _GHookMarshaller_c_wrapper();
 extern void _GHookMarshaller_c_wrapper_once();
-extern void _GIOFunc_c_wrapper();
-extern void _GIOFunc_c_wrapper_once();
+extern int _GIOFunc_c_wrapper();
+extern int _GIOFunc_c_wrapper_once();
 extern void _GLogFunc_c_wrapper();
 extern void _GLogFunc_c_wrapper_once();
-extern void _GLogWriterFunc_c_wrapper();
-extern void _GLogWriterFunc_c_wrapper_once();
+extern GLogWriterOutput _GLogWriterFunc_c_wrapper();
+extern GLogWriterOutput _GLogWriterFunc_c_wrapper_once();
 extern void _GNodeForeachFunc_c_wrapper();
 extern void _GNodeForeachFunc_c_wrapper_once();
-extern void _GNodeTraverseFunc_c_wrapper();
-extern void _GNodeTraverseFunc_c_wrapper_once();
-extern void _GOptionArgFunc_c_wrapper();
-extern void _GOptionArgFunc_c_wrapper_once();
+extern int _GNodeTraverseFunc_c_wrapper();
+extern int _GNodeTraverseFunc_c_wrapper_once();
+extern int _GOptionArgFunc_c_wrapper();
+extern int _GOptionArgFunc_c_wrapper_once();
 extern void _GOptionErrorFunc_c_wrapper();
 extern void _GOptionErrorFunc_c_wrapper_once();
-extern void _GOptionParseFunc_c_wrapper();
-extern void _GOptionParseFunc_c_wrapper_once();
-extern void _GPollFunc_c_wrapper();
-extern void _GPollFunc_c_wrapper_once();
+extern int _GOptionParseFunc_c_wrapper();
+extern int _GOptionParseFunc_c_wrapper_once();
+extern int32_t _GPollFunc_c_wrapper();
+extern int32_t _GPollFunc_c_wrapper_once();
 extern void _GPrintFunc_c_wrapper();
 extern void _GPrintFunc_c_wrapper_once();
-extern void _GRegexEvalCallback_c_wrapper();
-extern void _GRegexEvalCallback_c_wrapper_once();
+extern int _GRegexEvalCallback_c_wrapper();
+extern int _GRegexEvalCallback_c_wrapper_once();
 extern void _GScannerMsgFunc_c_wrapper();
 extern void _GScannerMsgFunc_c_wrapper_once();
-extern void _GSequenceIterCompareFunc_c_wrapper();
-extern void _GSequenceIterCompareFunc_c_wrapper_once();
+extern int32_t _GSequenceIterCompareFunc_c_wrapper();
+extern int32_t _GSequenceIterCompareFunc_c_wrapper_once();
 extern void _GSourceDisposeFunc_c_wrapper();
 extern void _GSourceDisposeFunc_c_wrapper_once();
 extern void _GSourceDummyMarshal_c_wrapper();
 extern void _GSourceDummyMarshal_c_wrapper_once();
-extern void _GSourceFunc_c_wrapper();
-extern void _GSourceFunc_c_wrapper_once();
+extern int _GSourceFunc_c_wrapper();
+extern int _GSourceFunc_c_wrapper_once();
 extern void _GSpawnChildSetupFunc_c_wrapper();
 extern void _GSpawnChildSetupFunc_c_wrapper_once();
 extern void _GTestDataFunc_c_wrapper();
@@ -142,16 +148,18 @@ extern void _GTestFixtureFunc_c_wrapper();
 extern void _GTestFixtureFunc_c_wrapper_once();
 extern void _GTestFunc_c_wrapper();
 extern void _GTestFunc_c_wrapper_once();
-extern void _GTestLogFatalFunc_c_wrapper();
-extern void _GTestLogFatalFunc_c_wrapper_once();
-extern void _GThreadFunc_c_wrapper();
-extern void _GThreadFunc_c_wrapper_once();
-extern void _GTranslateFunc_c_wrapper();
-extern void _GTranslateFunc_c_wrapper_once();
-extern void _GTraverseFunc_c_wrapper();
-extern void _GTraverseFunc_c_wrapper_once();
-extern void _GUnixFDSourceFunc_c_wrapper();
-extern void _GUnixFDSourceFunc_c_wrapper_once();
+extern int _GTestLogFatalFunc_c_wrapper();
+extern int _GTestLogFatalFunc_c_wrapper_once();
+extern void* _GThreadFunc_c_wrapper();
+extern void* _GThreadFunc_c_wrapper_once();
+extern char* _GTranslateFunc_c_wrapper();
+extern char* _GTranslateFunc_c_wrapper_once();
+extern int _GTraverseFunc_c_wrapper();
+extern int _GTraverseFunc_c_wrapper_once();
+extern int _GTraverseNodeFunc_c_wrapper();
+extern int _GTraverseNodeFunc_c_wrapper_once();
+extern int _GUnixFDSourceFunc_c_wrapper();
+extern int _GUnixFDSourceFunc_c_wrapper_once();
 extern void _GVoidFunc_c_wrapper();
 extern void _GVoidFunc_c_wrapper_once();
 extern void _GAsyncReadyCallback_c_wrapper();
@@ -166,54 +174,56 @@ extern void _GBusNameLostCallback_c_wrapper();
 extern void _GBusNameLostCallback_c_wrapper_once();
 extern void _GBusNameVanishedCallback_c_wrapper();
 extern void _GBusNameVanishedCallback_c_wrapper_once();
-extern void _GCancellableSourceFunc_c_wrapper();
-extern void _GCancellableSourceFunc_c_wrapper_once();
-extern void _GDBusInterfaceGetPropertyFunc_c_wrapper();
-extern void _GDBusInterfaceGetPropertyFunc_c_wrapper_once();
+extern int _GCancellableSourceFunc_c_wrapper();
+extern int _GCancellableSourceFunc_c_wrapper_once();
+extern GVariant* _GDBusInterfaceGetPropertyFunc_c_wrapper();
+extern GVariant* _GDBusInterfaceGetPropertyFunc_c_wrapper_once();
 extern void _GDBusInterfaceMethodCallFunc_c_wrapper();
 extern void _GDBusInterfaceMethodCallFunc_c_wrapper_once();
-extern void _GDBusInterfaceSetPropertyFunc_c_wrapper();
-extern void _GDBusInterfaceSetPropertyFunc_c_wrapper_once();
-extern void _GDBusMessageFilterFunction_c_wrapper();
-extern void _GDBusMessageFilterFunction_c_wrapper_once();
-extern void _GDBusProxyTypeFunc_c_wrapper();
-extern void _GDBusProxyTypeFunc_c_wrapper_once();
+extern int _GDBusInterfaceSetPropertyFunc_c_wrapper();
+extern int _GDBusInterfaceSetPropertyFunc_c_wrapper_once();
+extern GDBusMessage* _GDBusMessageFilterFunction_c_wrapper();
+extern GDBusMessage* _GDBusMessageFilterFunction_c_wrapper_once();
+extern GType _GDBusProxyTypeFunc_c_wrapper();
+extern GType _GDBusProxyTypeFunc_c_wrapper_once();
 extern void _GDBusSignalCallback_c_wrapper();
 extern void _GDBusSignalCallback_c_wrapper_once();
-extern void _GDBusSubtreeDispatchFunc_c_wrapper();
-extern void _GDBusSubtreeDispatchFunc_c_wrapper_once();
-extern void _GDBusSubtreeIntrospectFunc_c_wrapper();
-extern void _GDBusSubtreeIntrospectFunc_c_wrapper_once();
-extern void _GDatagramBasedSourceFunc_c_wrapper();
-extern void _GDatagramBasedSourceFunc_c_wrapper_once();
+extern GDBusInterfaceVTable* _GDBusSubtreeDispatchFunc_c_wrapper();
+extern GDBusInterfaceVTable* _GDBusSubtreeDispatchFunc_c_wrapper_once();
+extern char** _GDBusSubtreeEnumerateFunc_c_wrapper();
+extern char** _GDBusSubtreeEnumerateFunc_c_wrapper_once();
+extern GDBusInterfaceInfo** _GDBusSubtreeIntrospectFunc_c_wrapper();
+extern GDBusInterfaceInfo** _GDBusSubtreeIntrospectFunc_c_wrapper_once();
+extern int _GDatagramBasedSourceFunc_c_wrapper();
+extern int _GDatagramBasedSourceFunc_c_wrapper_once();
 extern void _GDesktopAppLaunchCallback_c_wrapper();
 extern void _GDesktopAppLaunchCallback_c_wrapper_once();
 extern void _GFileMeasureProgressCallback_c_wrapper();
 extern void _GFileMeasureProgressCallback_c_wrapper_once();
 extern void _GFileProgressCallback_c_wrapper();
 extern void _GFileProgressCallback_c_wrapper_once();
-extern void _GFileReadMoreCallback_c_wrapper();
-extern void _GFileReadMoreCallback_c_wrapper_once();
-extern void _GIOSchedulerJobFunc_c_wrapper();
-extern void _GIOSchedulerJobFunc_c_wrapper_once();
-extern void _GPollableSourceFunc_c_wrapper();
-extern void _GPollableSourceFunc_c_wrapper_once();
-extern void _GReallocFunc_c_wrapper();
-extern void _GReallocFunc_c_wrapper_once();
-extern void _GSettingsBindGetMapping_c_wrapper();
-extern void _GSettingsBindGetMapping_c_wrapper_once();
-extern void _GSettingsBindSetMapping_c_wrapper();
-extern void _GSettingsBindSetMapping_c_wrapper_once();
-extern void _GSettingsGetMapping_c_wrapper();
-extern void _GSettingsGetMapping_c_wrapper_once();
+extern int _GFileReadMoreCallback_c_wrapper();
+extern int _GFileReadMoreCallback_c_wrapper_once();
+extern int _GIOSchedulerJobFunc_c_wrapper();
+extern int _GIOSchedulerJobFunc_c_wrapper_once();
+extern int _GPollableSourceFunc_c_wrapper();
+extern int _GPollableSourceFunc_c_wrapper_once();
+extern void* _GReallocFunc_c_wrapper();
+extern void* _GReallocFunc_c_wrapper_once();
+extern int _GSettingsBindGetMapping_c_wrapper();
+extern int _GSettingsBindGetMapping_c_wrapper_once();
+extern GVariant* _GSettingsBindSetMapping_c_wrapper();
+extern GVariant* _GSettingsBindSetMapping_c_wrapper_once();
+extern int _GSettingsGetMapping_c_wrapper();
+extern int _GSettingsGetMapping_c_wrapper_once();
 extern void _GSimpleAsyncThreadFunc_c_wrapper();
 extern void _GSimpleAsyncThreadFunc_c_wrapper_once();
-extern void _GSocketSourceFunc_c_wrapper();
-extern void _GSocketSourceFunc_c_wrapper_once();
+extern int _GSocketSourceFunc_c_wrapper();
+extern int _GSocketSourceFunc_c_wrapper_once();
 extern void _GTaskThreadFunc_c_wrapper();
 extern void _GTaskThreadFunc_c_wrapper_once();
-extern void _GVfsFileLookupFunc_c_wrapper();
-extern void _GVfsFileLookupFunc_c_wrapper_once();
+extern GFile* _GVfsFileLookupFunc_c_wrapper();
+extern GFile* _GVfsFileLookupFunc_c_wrapper_once();
 void _g_drive_eject(GDrive* this, GMountUnmountFlags arg0, GCancellable* arg1, void* gofunc) {
 	if (gofunc) {
 		g_drive_eject(this, arg0, arg1, _GAsyncReadyCallback_c_wrapper_once, gofunc);
