@@ -118,6 +118,30 @@ func (this0 *Binding) GetStaticType() Type {
 func BindingGetType() Type {
 	return (*Binding)(nil).GetStaticType()
 }
+func (this0 *Binding) DupSource() *Object {
+	var this1 *C.GBinding
+	if this0 != nil {
+		this1 = (*C.GBinding)(this0.InheritedFromGBinding())
+	}
+	ret1 := C.g_binding_dup_source(this1)
+	var ret2 *Object
+
+//DEBUG: ret1(interface):flags = " conv_own_everything"
+	ret2 = (*Object)(ObjectWrap(unsafe.Pointer(ret1), false))
+	return ret2
+}
+func (this0 *Binding) DupTarget() *Object {
+	var this1 *C.GBinding
+	if this0 != nil {
+		this1 = (*C.GBinding)(this0.InheritedFromGBinding())
+	}
+	ret1 := C.g_binding_dup_target(this1)
+	var ret2 *Object
+
+//DEBUG: ret1(interface):flags = " conv_own_everything"
+	ret2 = (*Object)(ObjectWrap(unsafe.Pointer(ret1), false))
+	return ret2
+}
 func (this0 *Binding) GetFlags() BindingFlags {
 	var this1 *C.GBinding
 	if this0 != nil {
@@ -635,12 +659,10 @@ type EnumClass struct {
 	Minimum int32
 	Maximum int32
 	NValues uint32
-	_ [4]byte
 	Values *EnumValue
 }
 type EnumValue struct {
 	Value int32
-	_ [4]byte
 	value_name0 *C.char
 	value_nick0 *C.char
 }
@@ -662,7 +684,6 @@ type FlagsClass struct {
 }
 type FlagsValue struct {
 	Value uint32
-	_ [4]byte
 	value_name0 *C.char
 	value_nick0 *C.char
 }
@@ -835,7 +856,6 @@ const (
 type ParamSpecTypeInfo struct {
 	InstanceSize uint16
 	NPreallocs uint16
-	_ [4]byte
 	InstanceInit unsafe.Pointer
 	ValueType Type
 	Finalize unsafe.Pointer
@@ -852,6 +872,7 @@ type ParamSpecTypeInfo struct {
 // blacklisted: ParamSpecVariant (object)
 type Parameter struct {
 	name0 *C.char
+	_ [4]byte
 	Value Value
 }
 func (this0 *Parameter) Name() string {
@@ -874,6 +895,7 @@ const (
 	SignalFlagsNoHooks SignalFlags = 64
 	SignalFlagsMustCollect SignalFlags = 128
 	SignalFlagsDeprecated SignalFlags = 256
+	SignalFlagsAccumulatorFirstRun SignalFlags = 131072
 )
 type SignalInvocationHint struct {
 	SignalId uint32
@@ -891,14 +913,11 @@ const (
 )
 type SignalQuery struct {
 	SignalId uint32
-	_ [4]byte
 	signal_name0 *C.char
 	Itype Type
 	SignalFlags SignalFlags
-	_ [4]byte
 	ReturnType Type
 	NParams uint32
-	_ [4]byte
 	param_types0 *C.GType
 }
 func (this0 *SignalQuery) SignalName() string {
@@ -928,11 +947,11 @@ type TypeCValue struct {
 type TypeClass struct {
 	GType Type
 }
-func (this0 *TypeClass) AddPrivate(private_size0 uint64) {
+func (this0 *TypeClass) AddPrivate(private_size0 uint32) {
 	var this1 *C.GTypeClass
-	var private_size1 C.uint64_t
+	var private_size1 C.uint32_t
 	this1 = (*C.GTypeClass)(unsafe.Pointer(this0))
-	private_size1 = C.uint64_t(private_size0)
+	private_size1 = C.uint32_t(private_size0)
 	C.g_type_class_add_private(this1, private_size1)
 }
 func (this0 *TypeClass) GetPrivate(private_type0 Type) {
@@ -1005,7 +1024,7 @@ type TypeFundamentalInfo struct {
 }
 type TypeInfo struct {
 	ClassSize uint16
-	_ [6]byte
+	_ [2]byte
 	BaseInit unsafe.Pointer
 	BaseFinalize unsafe.Pointer
 	ClassInit unsafe.Pointer
@@ -1013,7 +1032,6 @@ type TypeInfo struct {
 	ClassData unsafe.Pointer
 	InstanceSize uint16
 	NPreallocs uint16
-	_ [4]byte
 	InstanceInit unsafe.Pointer
 	ValueTable *TypeValueTable
 }
@@ -1060,6 +1078,16 @@ func TypeInterfaceGetPlugin(instance_type0 Type, interface_type0 Type) *TypePlug
 	ret2 = (*TypePlugin)(ObjectWrap(unsafe.Pointer(ret1), true))
 	return ret2
 }
+func TypeInterfaceInstantiatablePrerequisite(interface_type0 Type) Type {
+	var interface_type1 C.GType
+	interface_type1 = C.GType(interface_type0)
+	ret1 := C.g_type_interface_instantiatable_prerequisite(interface_type1)
+	var ret2 Type
+
+//DEBUG: ret1(GType):flags = " conv_own_none"
+	ret2 = Type(ret1)
+	return ret2
+}
 func TypeInterfacePeek(instance_class0 *TypeClass, iface_type0 Type) *TypeInterface {
 	var instance_class1 *C.GTypeClass
 	var iface_type1 C.GType
@@ -1204,17 +1232,17 @@ func (this0 *TypeValueTable) LcopyFormat() string {
 	lcopy_format1 = C.GoString(this0.lcopy_format0)
 	return lcopy_format1
 }
+const ValueInternedString = 268435456
 const ValueNocopyContents = 134217728
 type Value struct {
 	GType Type
+	_ [4]byte
 	Data [2]_Value__data__union
 }
 type ValueArray struct {
 	NValues uint32
-	_ [4]byte
 	Values *Value
 	NPrealloced uint32
-	_ [4]byte
 }
 func NewValueArray(n_prealloced0 uint32) *ValueArray {
 	var n_prealloced1 C.uint32_t
@@ -1357,7 +1385,6 @@ type _Value__data__union struct {
 // blacklisted: param_spec_object (function)
 // blacklisted: param_spec_param (function)
 // blacklisted: param_spec_pointer (function)
-// blacklisted: param_spec_pool_new (function)
 // blacklisted: param_spec_string (function)
 // blacklisted: param_spec_uchar (function)
 // blacklisted: param_spec_uint (function)
@@ -1390,6 +1417,7 @@ type _Value__data__union struct {
 // blacklisted: signal_handlers_disconnect_matched (function)
 // blacklisted: signal_handlers_unblock_matched (function)
 // blacklisted: signal_has_handler_pending (function)
+// blacklisted: signal_is_valid_name (function)
 // blacklisted: signal_list_ids (function)
 // blacklisted: signal_lookup (function)
 // blacklisted: signal_name (function)
@@ -1437,6 +1465,7 @@ type _Value__data__union struct {
 // blacklisted: type_init_with_debug_flags (function)
 // blacklisted: type_interface_add_prerequisite (function)
 // blacklisted: type_interface_get_plugin (function)
+// blacklisted: type_interface_instantiatable_prerequisite (function)
 // blacklisted: type_interface_peek (function)
 // blacklisted: type_interface_prerequisites (function)
 // blacklisted: type_interfaces (function)
