@@ -182,8 +182,12 @@ typedef void* GDuplicateFunc;
 typedef void* GEqualFunc;
 typedef struct _GError GError;
 struct _GError { uint8_t _data[16]; };
+typedef void* GErrorClearFunc;
+typedef void* GErrorCopyFunc;
+typedef void* GErrorInitFunc;
 typedef uint32_t GErrorType;
 typedef uint32_t GFileError;
+typedef uint32_t GFileSetContentsFlags;
 typedef uint32_t GFileTest;
 typedef struct _GFloatIEEE754 GFloatIEEE754;
 struct _GFloatIEEE754 { uint8_t _data[4]; };
@@ -332,6 +336,8 @@ typedef struct _GString GString;
 struct _GString { uint8_t _data[24]; };
 typedef struct _GStringChunk GStringChunk;
 struct _GStringChunk {};
+typedef struct _GStrvBuilder GStrvBuilder;
+struct _GStrvBuilder {};
 typedef struct _GTestCase GTestCase;
 struct _GTestCase {};
 typedef struct _GTestConfig GTestConfig;
@@ -372,13 +378,24 @@ typedef struct _GTrashStack GTrashStack;
 struct _GTrashStack { uint8_t _data[8]; };
 typedef uint32_t GTraverseFlags;
 typedef void* GTraverseFunc;
+typedef void* GTraverseNodeFunc;
 typedef uint32_t GTraverseType;
 typedef struct _GTree GTree;
 struct _GTree {};
+typedef struct _GTreeNode GTreeNode;
+struct _GTreeNode {};
 typedef uint32_t GUnicodeBreakType;
 typedef int32_t GUnicodeScript;
 typedef uint32_t GUnicodeType;
 typedef void* GUnixFDSourceFunc;
+typedef struct _GUri GUri;
+struct _GUri {};
+typedef uint32_t GUriError;
+typedef uint32_t GUriFlags;
+typedef uint32_t GUriHideFlags;
+typedef uint32_t GUriParamsFlags;
+typedef struct _GUriParamsIter GUriParamsIter;
+struct _GUriParamsIter { uint8_t _data[280]; };
 typedef uint32_t GUserDirectory;
 typedef struct _GVariant GVariant;
 struct _GVariant {};
@@ -431,16 +448,23 @@ extern uint64_t g_udev_device_get_seqnum(GUdevDevice*);
 extern char* g_udev_device_get_subsystem(GUdevDevice*);
 extern char* g_udev_device_get_sysfs_attr(GUdevDevice*, char*);
 extern int g_udev_device_get_sysfs_attr_as_boolean(GUdevDevice*, char*);
+extern int g_udev_device_get_sysfs_attr_as_boolean_uncached(GUdevDevice*, char*);
 extern double g_udev_device_get_sysfs_attr_as_double(GUdevDevice*, char*);
+extern double g_udev_device_get_sysfs_attr_as_double_uncached(GUdevDevice*, char*);
 extern int32_t g_udev_device_get_sysfs_attr_as_int(GUdevDevice*, char*);
+extern int32_t g_udev_device_get_sysfs_attr_as_int_uncached(GUdevDevice*, char*);
 extern char** g_udev_device_get_sysfs_attr_as_strv(GUdevDevice*, char*);
+extern char** g_udev_device_get_sysfs_attr_as_strv_uncached(GUdevDevice*, char*);
 extern uint64_t g_udev_device_get_sysfs_attr_as_uint64(GUdevDevice*, char*);
+extern uint64_t g_udev_device_get_sysfs_attr_as_uint64_uncached(GUdevDevice*, char*);
 extern char** g_udev_device_get_sysfs_attr_keys(GUdevDevice*);
+extern char* g_udev_device_get_sysfs_attr_uncached(GUdevDevice*, char*);
 extern char* g_udev_device_get_sysfs_path(GUdevDevice*);
 extern char** g_udev_device_get_tags(GUdevDevice*);
 extern uint64_t g_udev_device_get_usec_since_initialized(GUdevDevice*);
 extern int g_udev_device_has_property(GUdevDevice*, char*);
 extern int g_udev_device_has_sysfs_attr(GUdevDevice*, char*);
+extern int g_udev_device_has_sysfs_attr_uncached(GUdevDevice*, char*);
 extern GType g_udev_device_get_type();
 extern GUdevEnumerator* g_udev_enumerator_new(GUdevClient*);
 extern GUdevEnumerator* g_udev_enumerator_add_match_is_initialized(GUdevEnumerator*);
