@@ -555,6 +555,21 @@ func (this0 *Device) GetSysfsAttrAsBoolean(name0 string) bool {
 	ret1 := C.g_udev_device_get_sysfs_attr_as_boolean(this1, name1)
 	var ret2 bool
 
+//DEBUG: ret1(gboolean):flags = " conv_own_none"
+	ret2 = ret1 != 0
+	return ret2
+}
+func (this0 *Device) GetSysfsAttrAsBooleanUncached(name0 string) bool {
+	var this1 *C.GUdevDevice
+	var name1 *C.char
+	if this0 != nil {
+		this1 = (*C.GUdevDevice)(this0.InheritedFromGUdevDevice())
+	}
+	name1 = _GoStringToGString(name0)
+	defer C.free(unsafe.Pointer(name1))
+	ret1 := C.g_udev_device_get_sysfs_attr_as_boolean_uncached(this1, name1)
+	var ret2 bool
+
 //DEBUG: ret1(gboolean):flags = " conv_own_none"
 	ret2 = ret1 != 0
 	return ret2
@@ -570,6 +585,21 @@ func (this0 *Device) GetSysfsAttrAsDouble(name0 string) float64 {
 	ret1 := C.g_udev_device_get_sysfs_attr_as_double(this1, name1)
 	var ret2 float64
 
+//DEBUG: ret1(gdouble):flags = " conv_own_none"
+	ret2 = float64(ret1)
+	return ret2
+}
+func (this0 *Device) GetSysfsAttrAsDoubleUncached(name0 string) float64 {
+	var this1 *C.GUdevDevice
+	var name1 *C.char
+	if this0 != nil {
+		this1 = (*C.GUdevDevice)(this0.InheritedFromGUdevDevice())
+	}
+	name1 = _GoStringToGString(name0)
+	defer C.free(unsafe.Pointer(name1))
+	ret1 := C.g_udev_device_get_sysfs_attr_as_double_uncached(this1, name1)
+	var ret2 float64
+
 //DEBUG: ret1(gdouble):flags = " conv_own_none"
 	ret2 = float64(ret1)
 	return ret2
@@ -585,6 +615,21 @@ func (this0 *Device) GetSysfsAttrAsInt(name0 string) int32 {
 	ret1 := C.g_udev_device_get_sysfs_attr_as_int(this1, name1)
 	var ret2 int32
 
+//DEBUG: ret1(gint32):flags = " conv_own_none"
+	ret2 = int32(ret1)
+	return ret2
+}
+func (this0 *Device) GetSysfsAttrAsIntUncached(name0 string) int32 {
+	var this1 *C.GUdevDevice
+	var name1 *C.char
+	if this0 != nil {
+		this1 = (*C.GUdevDevice)(this0.InheritedFromGUdevDevice())
+	}
+	name1 = _GoStringToGString(name0)
+	defer C.free(unsafe.Pointer(name1))
+	ret1 := C.g_udev_device_get_sysfs_attr_as_int_uncached(this1, name1)
+	var ret2 int32
+
 //DEBUG: ret1(gint32):flags = " conv_own_none"
 	ret2 = int32(ret1)
 	return ret2
@@ -600,6 +645,24 @@ func (this0 *Device) GetSysfsAttrAsStrv(name0 string) []string {
 	ret1 := C.g_udev_device_get_sysfs_attr_as_strv(this1, name1)
 	var ret2 []string
 
+//DEBUG: ret1(array):flags = " conv_own_none"
+	ret2 = make([]string, C._array_length(unsafe.Pointer(ret1)))
+	for i0 := range ret2 {
+		ret2[i0] = C.GoString((*(*[999999]*C.char)(unsafe.Pointer(ret1)))[i0])
+	}
+	return ret2
+}
+func (this0 *Device) GetSysfsAttrAsStrvUncached(name0 string) []string {
+	var this1 *C.GUdevDevice
+	var name1 *C.char
+	if this0 != nil {
+		this1 = (*C.GUdevDevice)(this0.InheritedFromGUdevDevice())
+	}
+	name1 = _GoStringToGString(name0)
+	defer C.free(unsafe.Pointer(name1))
+	ret1 := C.g_udev_device_get_sysfs_attr_as_strv_uncached(this1, name1)
+	var ret2 []string
+
 //DEBUG: ret1(array):flags = " conv_own_none"
 	ret2 = make([]string, C._array_length(unsafe.Pointer(ret1)))
 	for i0 := range ret2 {
@@ -618,6 +681,21 @@ func (this0 *Device) GetSysfsAttrAsUint64(name0 string) uint64 {
 	ret1 := C.g_udev_device_get_sysfs_attr_as_uint64(this1, name1)
 	var ret2 uint64
 
+//DEBUG: ret1(guint64):flags = " conv_own_none"
+	ret2 = uint64(ret1)
+	return ret2
+}
+func (this0 *Device) GetSysfsAttrAsUint64Uncached(name0 string) uint64 {
+	var this1 *C.GUdevDevice
+	var name1 *C.char
+	if this0 != nil {
+		this1 = (*C.GUdevDevice)(this0.InheritedFromGUdevDevice())
+	}
+	name1 = _GoStringToGString(name0)
+	defer C.free(unsafe.Pointer(name1))
+	ret1 := C.g_udev_device_get_sysfs_attr_as_uint64_uncached(this1, name1)
+	var ret2 uint64
+
 //DEBUG: ret1(guint64):flags = " conv_own_none"
 	ret2 = uint64(ret1)
 	return ret2
@@ -637,6 +715,21 @@ func (this0 *Device) GetSysfsAttrKeys() []string {
 	}
 	return ret2
 }
+func (this0 *Device) GetSysfsAttrUncached(name0 string) string {
+	var this1 *C.GUdevDevice
+	var name1 *C.char
+	if this0 != nil {
+		this1 = (*C.GUdevDevice)(this0.InheritedFromGUdevDevice())
+	}
+	name1 = _GoStringToGString(name0)
+	defer C.free(unsafe.Pointer(name1))
+	ret1 := C.g_udev_device_get_sysfs_attr_uncached(this1, name1)
+	var ret2 string
+
+//DEBUG: ret1(utf8):flags = " conv_own_none"
+	ret2 = C.GoString(ret1)
+	return ret2
+}
 func (this0 *Device) GetSysfsPath() string {
 	var this1 *C.GUdevDevice
 	if this0 != nil {
@@ -702,6 +795,21 @@ func (this0 *Device) HasSysfsAttr(key0 string) bool {
 	ret1 := C.g_udev_device_has_sysfs_attr(this1, key1)
 	var ret2 bool
 
+//DEBUG: ret1(gboolean):flags = " conv_own_none"
+	ret2 = ret1 != 0
+	return ret2
+}
+func (this0 *Device) HasSysfsAttrUncached(key0 string) bool {
+	var this1 *C.GUdevDevice
+	var key1 *C.char
+	if this0 != nil {
+		this1 = (*C.GUdevDevice)(this0.InheritedFromGUdevDevice())
+	}
+	key1 = _GoStringToGString(key0)
+	defer C.free(unsafe.Pointer(key1))
+	ret1 := C.g_udev_device_has_sysfs_attr_uncached(this1, key1)
+	var ret2 bool
+
 //DEBUG: ret1(gboolean):flags = " conv_own_none"
 	ret2 = ret1 != 0
 	return ret2
